#
# spec file for package ghc-comonad
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name comonad
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        5.0.9
Release:        2.3
Summary:        Comonads
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-distributive-devel
BuildRequires:  ghc-distributive-prof
BuildRequires:  ghc-indexed-traversable-devel
BuildRequires:  ghc-indexed-traversable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-compat-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
Comonads.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.markdown README.markdown examples

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Mar  2 2025 Peter Simons <psimons@suse.com>
- Update comonad to version 5.0.9 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Dec  4 2024 Peter Simons <psimons@suse.com>
- Update comonad to version 5.0.9.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/comonad-5.0.9/src/CHANGELOG.markdown
* Sat Sep 30 2023 Peter Simons <psimons@suse.com>
- Update comonad to version 5.0.8 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Aug  4 2021 psimons@suse.com
- Update comonad to version 5.0.8 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Dec 30 2020 psimons@suse.com
- Update comonad to version 5.0.8.
  5.0.8 [2020.12.30]
  - -----------------
  * Explicitly mark modules as Safe or Trustworthy.
  * The build-type has been changed from `Custom` to `Simple`.
    To achieve this, the `doctests` test suite has been removed in favor of using
    [`cabal-docspec`](https://github.com/phadej/cabal-extras/tree/master/cabal-docspec)
    to run the doctests.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Wed Dec 16 2020 psimons@suse.com
- Update comonad to version 5.0.7.
  5.0.7 [2020.12.15]
  - -----------------
  * Move `FunctorWithIndex (TracedT m w)` instance from `lens`.
    This instance depends on the `indexed-traversable` package. This can be disabled using the flag of the same name.
* Mon Aug 31 2020 psimons@suse.com
- Update comonad to version 5.0.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Wed Nov 27 2019 psimons@suse.com
- Update comonad to version 5.0.6.
  5.0.6 [2019.11.26]
  - -----------------
  * Achieve forward compatibility with
    [GHC proposal 229](https://github.com/ghc-proposals/ghc-proposals/blob/master/proposals/0229-whitespace-bang-patterns.rst).
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri May  3 2019 psimons@suse.com
- Update comonad to version 5.0.5.
  5.0.5 [2019.05.02]
  - -----------------
  * Raised the minimum `semigroups` version to 0.16.2. In addition, the
    package will only be required at all for GHCs before 8.0.
  * Drop the `contravariant` flag from `comonad.cabal`, as `comonad` no longer
    depends on the `contravariant` library.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update comonad to version 5.0.4.
  5.0.4 [2018.07.01]
  - -----------------
  * Add `Comonad` instances for `Tagged s` with `s` of any kind. Before the
    change, `s` had to be of kind `*`.
  * Allow `containers-0.6`.
* Mon May 14 2018 psimons@suse.com
- Update comonad to version 5.0.3 revision 2.
  * Don't enable `Safe` on GHC 7.2.
  * Support `doctest-0.12`
* Mon Apr 24 2017 psimons@suse.com
- Update to version 5.0.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 5 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 4.2.7.2 revision 0 with cabal2obs.
* Mon Jul 27 2015 mimi.vx@gmail.com
- update to 4.2.7.2
  * Compiles warning-free on GHC 7.10
  * Use CPP
  * Trustworthy fixes for GHC 7.2
* Thu May 21 2015 mimi.vx@gmail.com
- correct licence to BSD-2-Clause
* Sun May 17 2015 mimi.vx@gmail.com
- update to 4.2.6
  * Re-export `(Data.Functor.$>)` rather than supply our own on GHC 7.8+
  * Better SafeHaskell support.
  * `instance Monoid m => ComonadTraced m ((->) m)`
* Sun Apr 26 2015 mimi.vx@gmail.com
- initial commit
